<?php
/**
 * Plugin Filehtml (addon for plugin Adm_redacteurs)
 * Version  : 1.6 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00 et Adm_redacteurs v6.14+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Filehtml_counters_model extends Model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_counter = 0; // Valeur du compteur
    private $_file_dir_path = FILEHTML_COUNTERS_PATH; // Chemin du répertoire contenant les compteurs
    private $_file_prefix = FILEHTML_COUNTERS_FILE_PREFIX; // Préfixe du fichier du compteur
    private $_file_ext = DBEXT; // Exyension du fichier du compteur
    private $_DB_file_path = '';  // Chemin du fichier du compteur

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct($doc_id = 0)
	{
        $this -> load_counter($doc_id);
	}
    
	// --------------------------------------------------------------------
 
	/**
	 * Charge la valeur du compteur
     * 
     * @access public 
	 * @param integer Identifiant du document
	 * @return integer Valeur du compteur de vues
	 */    
    public function load_counter($doc_id)
    {
        if (!empty($doc_id) && ctype_digit($doc_id)) {
            $this -> _DB_file_path = $this -> _get_file_path($doc_id);

            if (! is_file($this -> _DB_file_path)) {
                $this -> _write();    
            }
            
            $this -> _counter = $this -> _read();   
        }
        
        return $this -> _counter;       
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le nom des fichiers enregistrés dans la base de donnée
     * 
     * @access public 
	 * @return boolean
	 */
    public function get_all_files()
	{
        $files = array();
        
        if (!empty($this -> _file_dir_path)) {
            $files = array_slice(scandir($this -> _file_dir_path), 2);
            unset($files[array_search('index.php', $files)]); // Suppression du fichier index.php
        }
        
        return $files;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie les identifiants des fichiers enregistrés dans la base de donnée
     * 
     * @access public 
	 * @return boolean
	 */
    public function get_files_ids()
	{
        $files_ids = array();
        $files = $this -> get_all_files();

        foreach($files as $key => $file) {
            $files_ids[] = str_replace(array($this -> _file_prefix, $this -> _file_ext), '', $file);
        }
        
        return $files_ids;
	}

	// --------------------------------------------------------------------

	/**
	 * Vérifie si le document existe ou non
     * 
     * @access public 
	 * @param integer Identifiant du document
	 * @return boolean
	 */
    public function file_exists($doc_id = 0)
	{
        if (!empty($doc_id) && ctype_digit((string) $doc_id) && is_file($this -> _get_file_path($doc_id))) {            
            return TRUE;    
        }
        
        return FALSE;
	}

	// --------------------------------------------------------------------

	/**
	 * Augmente le compteur de vues du document identifié par la valeur de son id
     * 
     * @access public 
	 * @return array Tableau contenant les valeurs du document
	 */
    public function increase_counter()
    {
        $this -> _counter++;
        
        return $this -> _write(); 
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le nombre de vues du document identifié par la valeur de son id
     * 
     * @access public 
	 * @param integer Identifiant du document
	 * @return array Tableau contenant les valeurs du document
	 */
    public function get_counter()
    {
        return $this -> _counter; 
    }

	// --------------------------------------------------------------------

	/**
	 * Remet à zéro le compteur
     * 
     * @access public 
	 * @return integer Valeur du compteur
	 */
    public function reset_counter()
    {
        $this -> _counter = 0;
        $this -> _write();
        
        return $this -> _counter; 
    }

	// --------------------------------------------------------------------

	/**
	 * Définit la valeur enregistrée dans le compteur
     * 
     * @access public 
	 * @param integer Valeur du compteur
	 * @return integer Valeur du compteur
	 */
    public function define_counter($counter)
    {
        settype($counter, 'integer');
        
        if ($counter >= 0) {
            $this -> _counter = $counter;
            $this -> _write();        
        }
        
        return $this -> _counter; 
    }

	// --------------------------------------------------------------------
 
	/**
	 * Supprime les documents identifiés par leur id
     * 
     * @access public 
     * @param array|integer Identifiants des documents à supprimer
	 * @return boolean
	 */    
    public function delete_by_id($doc_ids)
    {
        settype($doc_ids, 'array');

        if (empty($this -> _file_dir_path) || empty($doc_ids)) {
            return FALSE;
        }
                
        foreach($doc_ids as $doc_id) {
            if ($this -> file_exists($doc_id)) {
                @unlink($this -> _get_file_path($doc_id));    
            }
        }
       
        return TRUE; 
    }

	// --------------------------------------------------------------------

	/**
	 * Lit et renvoie dans un tableau les données enregistrées dans le document identifié par la valeur de son id
     * 
     * @access public
	 * @return array Tableau contenant les valeurs du document
	 */
    protected function _read()
    {
        $counter = '0';
        
        if (!empty($this -> _DB_file_path)) {
            $counter = file_get_contents($this -> _DB_file_path);
        }
       
        return $counter; 
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ecrit les données du document dans un fichier
     * 
     * @access public 
     * @param array Données du rédacteur ou du groupe rédacteur
	 * @return array
	 */    
    protected function _write()
    {
        $counter = $this -> _counter;
        $file_path = $this -> _DB_file_path;
        
        if (empty($file_path) || !ctype_digit((string) $counter)) { // Si pas de fichier ou compteur non entier, on a rien à faire ici !
            return FALSE;    
        }
        
		return file_put_contents($file_path, $counter, LOCK_EX);
    }
   
	// --------------------------------------------------------------------
 
	/**
	 * Retourne le chemin du fichier associé à l'id passé en paramètre
     * 
     * @access private 
     * @param integer Id du document
	 * @return string Chemin du fichier associé à l'id passé en paramètre
	 */    
    private function _get_file_path($doc_id)
    {
        return $this -> _file_dir_path.'/'.$this -> _file_prefix.$doc_id.$this -> _file_ext;    
    }
     
	// --------------------------------------------------------------------

} // End of Class